import { EnumCodeFormat } from '../enum/enumcodeformat';
import { ParseResult } from '../interface/parseresult';
export default class CodeParser {
    private static _jsVersion;
    private static _jsEditVersion;
    protected static _version: string;
    /**
      * Get the current version.
    */
    static getVersion(): string;
    protected static _license: string;
    static get license(): string;
    /**
     * Get or set the Dynamsoft Code Parser SDK product keys.
     * ```js
     * Dynamsoft.DCP.CodeParser.license = "PRODUCT-KEYS";
     * ```
     * For convenience, you can set `license` in `script` tag instead.
     * ```html
     * <script src="https://cdn.jsdelivr.net/npm/dynamsoft-code-parser@1.0.0/dist/dcp.js" data-license="PRODUCT-KEYS"></script>
     * ```
    */
    static set license(license: string);
    static _workerName: string;
    static _bWasmDebug: boolean;
    static _onLog: any;
    private static _pLoad;
    static _bNeverShowDialog: boolean;
    protected static _sessionPassword: string;
    /**
     * Specify a password to protect the `online key` from abuse.
     * ```js
     * Dynamsoft.DCP.CodeParser.license = "123****-mytest";
     * Dynamsoft.DCP.CodeParser.sessionPassword = "@#$%****";
     * ```
     * Since js in the browser is plaintext, it is not safe to set a password. It is recommended that you bind the `domain` as `Validation field` in the [handshake settings in dynamsoft website](https://www.dynamsoft.com/lts/index.html#/handshakeCodes) or your self-hosted license server.
     *
     * In nodejs, password is meaningful.
     * @see [[license]]
     */
    static set sessionPassword(value: string);
    static get sessionPassword(): string;
    /**
      * @ignore
    */
    static browserInfo: {
        browser: string;
        version: string | number;
        OS: string;
    };
    /**
    * Detect environment and get a report.
    * ```js
    * console.log(await Dynamsoft.DCP.CodeParser.detectEnvironment());
    * // {"wasm":true, "worker":true, "getUserMedia":true, "camera":true, "browser":"Chrome", "version":90, "OS":"Windows"}
    * ```
    */
    static detectEnvironment(): Promise<any>;
    protected static __bUseFullFeature: boolean;
    static get _bUseFullFeature(): boolean;
    static set _bUseFullFeature(value: boolean);
    private static _deviceFriendlyName;
    static get deviceFriendlyName(): string;
    static set deviceFriendlyName(value: string);
    protected static _taskCallbackMap: Map<number, (body: any) => void>;
    _instanceID: number;
    static _dcpWorker: Worker;
    protected static _nextTaskID: number;
    _lastInnerParseDuration: number;
    protected bDestroyed: boolean;
    /** @ignore */
    protected static _engineResourcePath?: string;
    static get engineResourcePath(): string;
    /**
     * Specify the Code Parser SDK engine (WASM) url. The SDK tries to automatically explore the engine location.
     * If the auto-explored engine location is incorrect, you can manually specify the engine location.
     * The property needs to be set before [[loadWasm]].
     * ```js
     * Dynamsoft.DCP.CodeParser.engineResourcePath = "https://cdn.jsdelivr.net/npm/dynamsoft-code-parser@1.0.0/dist/";
     * await Dynamsoft.DCP.CodeParser.loadWasm();
     * ```
    */
    static set engineResourcePath(value: string);
    /** @ignore */
    protected static _licenseServer?: string[];
    static get licenseServer(): string[] | string;
    /**
     * Specify the license server URL.
    */
    static set licenseServer(value: string[] | string);
    /**
     * Before most operations, `loadWasm` needs to be excuted firstly.
     * Most time, you do not need excute `loadWasm` manually. Because when you excute [[createInstance]], `loadWasm` will be excuted implicitly.
     * Some properties can't be changed after `loadWasm`.
     * Calling `loadWasm` in advance can avoid the long wait when `createInstance`.
     * ```js
     * window.addEventListener('DOMContentLoaded', (event) => {
     *   DCP.CodeParser.loadWasm();
     * });
     * ```
     * @category Initialize and Destroy
    */
    static loadWasm(): Promise<void>;
    protected static showDialog(type: string, content: string): Promise<void>;
    protected static createInstanceInWorker(): Promise<number>;
    /**
    * Create a `CodeParser` instance.
    * ```
    * let pParser = null;
    * (async()=>{
    *     let parser = await (pParser = pParser || Dynamsoft.DCP.CodeParser.createInstance());
    * })();
    * ```
      * @category Initialize and Destroy
    */
    static createInstance(): Promise<CodeParser>;
    /**
     * Set the public key for parsing
     * parser.setCryptoPublicKey('your public key');
    */
    setCryptoPublicKey(key: string): Promise<void>;
    /**
     * Set the certificate for parsing
     * parser.setCertificate('your certificate');
    */
    setCertificate(certificate: Uint8Array | ArrayBuffer | string): Promise<void>;
    /**
     * Set the content format to be parsed
     * parser.setCodeFormat('value of type EnumCodeFormat');
    */
    _currentFormat: EnumCodeFormat;
    setCodeFormat(format: EnumCodeFormat): Promise<void>;
    /**
     * Parse the content
     * parser.parseData('parse the content');
    */
    parseData(source: number[] | Uint8Array | string): Promise<ParseResult>;
    private _getDLResult;
    private _getVDSResult;
    private _stringToUint8Array;
    /**
     * Convert the results to the correct format
    */
    private _formatResult;
    /**
     * Get description by result code
    */
    private _setDescription;
    /**
      * Destroy the `CodeParser` instance. If your page needs to create new instances from time to time, don't forget to destroy unused old instances, otherwise it will cause memory leaks.
      * @category Initialize and Destroy
    */
    destroyContext(): void;
}
//# sourceMappingURL=codeparser.d.ts.map